@@ -1,9 +1,23 @@
+enroll_rate <- define_enroll_rate(
+  duration = 18,
+  rate = 20
+)
+
+# Failure rates
+fail_rate <- define_fail_rate(
+  duration = c(4, 100),
+  fail_rate = log(2) / 12,
+  dropout_rate = .001,
+  hr = c(1, .6)
+)
+
+# Study duration in months
+study_duration <- 36
+
+# Experimental / Control randomization ratio
+ratio <- 1
+
 test_that("AHR", {
-  res <- test_fixed_design()
-  enroll_rate <- res$enroll_rate
-  fail_rate <- res$fail_rate
-  study_duration <- res$study_duration
-  ratio <- res$ratio
 
   x <- fixed_design_ahr(
     alpha = 0.025,
@@ -26,11 +40,6 @@ test_that("AHR", {
 })
 
 test_that("FH", {
-  res <- test_fixed_design()
-  enroll_rate <- res$enroll_rate
-  fail_rate <- res$fail_rate
-  study_duration <- res$study_duration
-  ratio <- res$ratio
 
   x <- fixed_design_fh(
     alpha = 0.025,
@@ -58,11 +67,6 @@ test_that("FH", {
 })
 
 test_that("MB", {
-  res <- test_fixed_design()
-  enroll_rate <- res$enroll_rate
-  fail_rate <- res$fail_rate
-  study_duration <- res$study_duration
-  ratio <- res$ratio
 
   x <- fixed_design_mb(
     alpha = 0.025,
@@ -88,11 +92,6 @@ test_that("MB", {
 })
 
 test_that("LF", {
-  res <- test_fixed_design()
-  enroll_rate <- res$enroll_rate
-  fail_rate <- res$fail_rate
-  study_duration <- res$study_duration
-  ratio <- res$ratio
 
   x <- fixed_design_lf(
     alpha = 0.025,
@@ -115,11 +114,6 @@ test_that("LF", {
 })
 
 test_that("MaxCombo", {
-  res <- test_fixed_design()
-  enroll_rate <- res$enroll_rate
-  fail_rate <- res$fail_rate
-  study_duration <- res$study_duration
-  ratio <- res$ratio
 
   x <- fixed_design_maxcombo(
     alpha = 0.025,
@@ -144,15 +138,10 @@ test_that("MaxCombo", {
     tau = c(-1, 4, 6)
   )
 
-  expect_equal(y$analysis$power, 0.9, tolerance = testthat_tolerance() * 100)
+  expect_equal(y$analysis$power, 0.9, tolerance = 1e-4)
 })
 
 test_that("RMST", {
-  res <- test_fixed_design()
-  enroll_rate <- res$enroll_rate
-  fail_rate <- res$fail_rate
-  study_duration <- res$study_duration
-  ratio <- res$ratio
 
   x <- fixed_design_rmst(
     alpha = 0.025,
@@ -177,11 +166,6 @@ test_that("RMST", {
 })
 
 test_that("RD", {
-  res <- test_fixed_design()
-  enroll_rate <- res$enroll_rate
-  fail_rate <- res$fail_rate
-  study_duration <- res$study_duration
-  ratio <- res$ratio
 
   x <- fixed_design_rd(
     alpha = 0.025,
